==> meta_permissions-0.1.4-py3-none-any.whl: meta_permissions/codenames/tmg.py <==
tmg = [
    "edc_action_item.add_actionitem",
    "edc_action_item.change_actionitem",
    "edc_action_item.delete_actionitem",
    "edc_action_item.view_actionitem",
    "edc_action_item.view_actiontype",
    "edc_action_item.view_historicalactionitem",
    "edc_action_item.view_historicalreference",
    "edc_action_item.view_reference",
    "edc_adverse_event.view_aeclassification",
    "edc_adverse_event.view_causeofdeath",
    "edc_adverse_event.view_saereason",
    "edc_appointment.view_appointment",
    "edc_appointment.view_historicalappointment",
    "edc_dashboard.view_ae_listboard",
    "edc_dashboard.view_screening_listboard",
    "edc_dashboard.view_subject_listboard",
    "edc_dashboard.view_subject_review_listboard",
    "edc_dashboard.view_tmg_listboard",
    "edc_navbar.nav_ae_section",
    "edc_navbar.nav_screening_section",
    "edc_navbar.nav_subject_section",
    "edc_navbar.nav_tmg_section",
    "meta_ae.add_aetmg",
    "meta_ae.add_deathreporttmg",
    "meta_ae.add_deathreporttmgsecond",
    "meta_ae.change_aetmg",
    "meta_ae.change_deathreporttmg",
    "meta_ae.change_deathreporttmgsecond",
    "meta_ae.delete_aetmg",
    "meta_ae.delete_deathreporttmg",
    "meta_ae.delete_deathreporttmgsecond" "meta_ae.view_aefollowup",
    "meta_ae.view_aeinitial",
    "meta_ae.view_aesusar",
    "meta_ae.view_aetmg",
    "meta_ae.view_deathreport",
    "meta_ae.view_deathreporttmg",
    "meta_ae.view_deathreporttmgsecond",
    "meta_ae.view_historicalaefollowup",
    "meta_ae.view_historicalaeinitial",
    "meta_ae.view_historicalaesusar",
    "meta_ae.view_historicalaetmg",
    "meta_ae.view_historicaldeathreport",
    "meta_ae.view_historicaldeathreporttmg",
    "meta_ae.view_historicaldeathreporttmgsecond",
    "meta_lists.view_arvregimens",
    "meta_lists.view_baselinesymptoms",
    "meta_lists.view_diabetessymptoms",
    "meta_lists.view_offstudyreasons",
    "meta_lists.view_oiprophylaxis",
    "meta_lists.view_symptoms",
    "meta_subject.view_bloodresultsfbc",
    "meta_subject.view_bloodresultsglu",
    "meta_subject.view_bloodresultshba1c",
    "meta_subject.view_bloodresultslft",
    "meta_subject.view_bloodresultsrft",
    "meta_subject.view_complications",
    "meta_subject.view_followup",
    "meta_subject.view_followupvitals",
    "meta_subject.view_healtheconomics",
    "meta_subject.view_historicalbloodresultsfbc",
    "meta_subject.view_historicalbloodresultsglu",
    "meta_subject.view_historicalbloodresultshba1c",
    "meta_subject.view_historicalbloodresultslft",
    "meta_subject.view_historicalbloodresultsrft",
    "meta_subject.view_historicalcomplications",
    "meta_subject.view_historicalfollowup",
    "meta_subject.view_historicalfollowupvitals",
    "meta_subject.view_historicalhealtheconomics",
    "meta_subject.view_historicalmalariarapidtest",
    "meta_subject.view_historicalmedicationadherence",
    "meta_subject.view_historicalpatienthistory",
    "meta_subject.view_historicalsubjectrequisition",
    "meta_subject.view_historicalsubjectvisit",
    "meta_subject.view_historicalurinedipsticktest",
    "meta_subject.view_malariarapidtest",
    "meta_subject.view_medicationadherence",
    "meta_subject.view_patienthistory",
    "meta_subject.view_subjectrequisition",
    "meta_subject.view_subjectvisit",
    "meta_subject.view_urinedipsticktest",
]
tmg.sort()

==> meta_permissions-0.1.5-py3-none-any.whl: meta_permissions/codenames/tmg.py <==
from edc_permissions.codenames import tmg

tmg += [
    "meta_ae.add_aetmg",
    "meta_ae.add_deathreporttmg",
    "meta_ae.add_deathreporttmgsecond",
    "meta_ae.add_deathreporttmgsecond",
    "meta_ae.change_aetmg",
    "meta_ae.change_deathreporttmg",
    "meta_ae.change_deathreporttmgsecond",
    "meta_ae.change_deathreporttmgsecond",
    "meta_ae.delete_aetmg",
    "meta_ae.delete_deathreporttmg",
    "meta_ae.delete_deathreporttmgsecond",
    "meta_ae.delete_deathreporttmgsecond",
    "meta_ae.view_aefollowup",
    "meta_ae.view_aeinitial",
    "meta_ae.view_aesusar",
    "meta_ae.view_aetmg",
    "meta_ae.view_deathreport",
    "meta_ae.view_deathreporttmg",
    "meta_ae.view_deathreporttmgsecond",
    "meta_ae.view_historicalaefollowup",
    "meta_ae.view_historicalaeinitial",
    "meta_ae.view_historicalaesusar",
    "meta_ae.view_historicalaetmg",
    "meta_ae.view_historicaldeathreport",
    "meta_ae.view_historicaldeathreporttmg",
    "meta_ae.view_historicaldeathreporttmgsecond",
    "meta_lists.view_arvregimens",
    "meta_lists.view_baselinesymptoms",
    "meta_lists.view_diabetessymptoms",
    "meta_lists.view_offstudyreasons",
    "meta_lists.view_oiprophylaxis",
    "meta_lists.view_symptoms",
    "meta_subject.view_bloodresultsfbc",
    "meta_subject.view_bloodresultsglu",
    "meta_subject.view_bloodresultshba1c",
    "meta_subject.view_bloodresultslft",
    "meta_subject.view_bloodresultsrft",
    "meta_subject.view_complications",
    "meta_subject.view_followup",
    "meta_subject.view_followupvitals",
    "meta_subject.view_healtheconomics",
    "meta_subject.view_historicalbloodresultsfbc",
    "meta_subject.view_historicalbloodresultsglu",
    "meta_subject.view_historicalbloodresultshba1c",
    "meta_subject.view_historicalbloodresultslft",
    "meta_subject.view_historicalbloodresultsrft",
    "meta_subject.view_historicalcomplications",
    "meta_subject.view_historicalfollowup",
    "meta_subject.view_historicalfollowupvitals",
    "meta_subject.view_historicalhealtheconomics",
    "meta_subject.view_historicalmalariarapidtest",
    "meta_subject.view_historicalmedicationadherence",
    "meta_subject.view_historicalpatienthistory",
    "meta_subject.view_historicalphysicalexam",
    "meta_subject.view_historicalsubjectrequisition",
    "meta_subject.view_historicalsubjectvisit",
    "meta_subject.view_historicalurinedipsticktest",
    "meta_subject.view_malariarapidtest",
    "meta_subject.view_medicationadherence",
    "meta_subject.view_patienthistory",
    "meta_subject.view_physicalexam",
    "meta_subject.view_subjectrequisition",
    "meta_subject.view_subjectvisit",
    "meta_subject.view_urinedipsticktest",
]
tmg.sort()
